@@ -13,21 +13,21 @@ sub match {
     #                           1: Matched
     # @since v5.0.0
     my $class = shift;
-    my $argv1 = shift // return undef;
+    my $argv1 = shift // return 0;
 
     state $index = [
-        '//spf.pobox.com',
-        'bad spf records for',
-        'dmarc policy',
-        'please inspect your spf settings',
-        'sender policy framework (spf) fail',
-        'sender policy framework violation',
-        'spf (sender policy framework) domain authentication fail',
-        'spf check: fail',
+        "//spf.pobox.com",
+        "5322.From address doesn't meet the authentication requirements",
+        "bad spf records for",
+        "dmarc policy",
+        "doesn't meet the required authentication level",
+        "please inspect your spf settings",
+        "sender policy framework",
+        "spf check: fail",
     ];
     state $pairs = [
-        [' is not allowed to send mail.', '_401'],
-        ['is not allowed to send from <', " per it's spf record"],
+        [" is not allowed to send mail.", "_401"],
+        ["is not allowed to send from <", " per it's spf record"],
     ];
 
     return 1 if grep { rindex($argv1, $_) > -1 } @$index;
@@ -43,12 +43,11 @@ sub true {
     # @see http://www.ietf.org/rfc/rfc2822.txt
     # @since v5.0.0
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argvs = shift // return 0;
 
     return 1 if $argvs->{'reason'} eq 'authfailure';
     return 1 if (Sisimai::SMTP::Status->name($argvs->{'deliverystatus'}) || '') eq 'authfailure';
-    return 1 if __PACKAGE__->match(lc $argvs->{'diagnosticcode'});
-    return 0;
+    return __PACKAGE__->match(lc $argvs->{'diagnosticcode'});
 }
 
 1;
@@ -103,7 +102,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2022-2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2022-2026 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
