@@ -15,70 +15,58 @@ sub match {
     my $argv1 = shift // return 0;
 
     state $isnot = [
-        '5.1.0 address rejected',
-        'recipient address rejected',
-        'sender ip address rejected',
+        "5.1.0 address rejected",
+        "ip address ",
+        "recipient address rejected",
     ];
     state $index = [
-        'access denied (in reply to mail from command)',
-        'access denied (sender blacklisted)',
-        'address rejected',
-        'administrative prohibition',
-        'batv failed to verify',    # SoniWall
-        'batv validation failure',  # SoniWall
-        'backscatter protection detected an invalid or expired email address',  # MDaemon
-        "because the sender isn't on the recipient's list of senders to accept mail from",
-        'bogus mail from',          # IMail - block empty sender
+        "access denied (in reply to mail from command)",
+        "administrative prohibition",
+        "all recipient addresses rejected : access denied",
+        "backscatter protection detected an invalid or expired email address", # MDaemon
+        "by non-member to a members-only list",
         "can't determine purported responsible address",
-        'connections not accepted from servers without a valid sender domain',
-        'denied [bouncedeny]',      # McAfee
-        'denied by secumail valid-address-filter',
-        'delivery not authorized, message refused',
-        'does not exist e2110',
-        'domain of sender address ',
-        'email address is on senderfilterconfig list',
-        'emetteur invalide',
-        'empty envelope senders not allowed',
-        'envelope blocked - ',
-        'error: no third-party dsns',   # SpamWall - block empty sender
-        'from: domain is invalid. please provide a valid from:',
-        'fully qualified email address required',   # McAfee
-        'invalid domain, see <url:',
-        'invalid sender',
-        'is not a registered gateway user',
-        'mail from not owned by user',
-        'message rejected: email address is not verified',
-        'mx records for ',
-        'null sender is not allowed',
-        'recipient addresses rejected : access denied',
-        'recipient not accepted. (batv: no tag',
-        'returned mail not accepted here',
-        'rfc 1035 violation: recursive cname records for',
-        'rule imposed mailbox access for',  # MailMarshal
-        'sending this from a different address or alias using the ',
-        'sender address has been blacklisted',
-        'sender email address rejected',
-        'sender is in my black list',
-        'sender is spammer',
-        'sender not pre-approved',
-        'sender rejected',
-        'sender domain is empty',
-        'sender verify failed',     # Exim callout
-        'sender was rejected',      # qmail
-        'spam reporting address',   # SendGrid|a message to an address has previously been marked as Spam by the recipient.
-        'syntax error: empty email address',
-        'the message has been rejected by batv defense',
-        'this server does not accept mail from',
-        'transaction failed unsigned dsn for',
-        'unroutable sender address',
-        'you are not allowed to post to this mailing list',
-        'you are sending to/from an address that has been blacklisted',
-        'your access to submit messages to this e-mail system has been rejected',
-        'your email address has been blacklisted',  # MessageLabs
+        "connections not accepted from servers without a valid sender domain",
+        "denied by secumail valid-address-filter", # SecuMail
+        "domain of sender address ",
+        "email address is on senderfilterconfig list",
+        "emetteur invalide",
+        "empty email address",
+        "empty envelope senders not allowed",
+        "from: domain is invalid. please provide a valid from:",
+        "fully qualified email address required",   # McAfee
+        "invalid sender",
+        "is not a registered gateway user",
+        "mail from not owned by user",
+        "mailfrom domain is listed in spamhaus",
+        "null sender is not allowed",
+        "returned mail not accepted here",
+        "sending this from a different address or alias using the ",
+        "sender is spammer",
+        "sender not pre-approved",
+        "sender domain is empty",
+        "sender domain listed at ",
+        "sender verify failed",     # Exim callout
+        "server does not accept mail from",
+        "spam reporting address",   # SendGrid|a message to an address has previously been marked as Spam by the recipient.
+        "unroutable sender address",
+        "you are not allowed to post to this mailing list",
+        "your access to submit messages to this e-mail system has been rejected",
+        "your email address has been blacklisted",  # MessageLabs
+    ];
+    state $pairs = [
+        ["after end of data:", ".", " does not exist"],
+        ["after mail from:", ".", " does not exist"],
+        ["domain ", " is a dead domain"],
+        ["email address ", "is not "],
+        ["send", "blacklisted"],
+        ["sender", " rejected"],
+        ["sender is", " list"],
     ];
 
     return 0 if grep { rindex($argv1, $_) > -1 } @$isnot;
     return 1 if grep { rindex($argv1, $_) > -1 } @$index;
+    return 1 if grep { Sisimai::String->aligned(\$argv1, $_) } @$pairs;
     return 0;
 }
 
@@ -171,7 +159,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2019,2021-2025 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2019,2021-2026 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
