@@ -16,118 +16,87 @@ sub match {
     my $argv1 = shift // return 0;
 
     state $index = [
-        '#5.1.1 bad address',
-        '550 address invalid',
-        '5.1.0 address rejected.',
-        'address does not exist',
-        'address not present in directory',
-        'address unknown',
+        "#5.1.1 bad address",
+        "550 address invalid",
+        "5.1.0 address rejected.",
+        "address not present in directory",
+        "address unknown",
+        "badrcptto",
         "can't accept user",
-        'does not exist.',
-        'destination addresses were unknown',
-        'destination server rejected recipients',
-        'email address does not exist',
-        'email address could not be found',
-        'invalid address',
-        'invalid mailbox',
-        'invalid mailbox path',
-        'invalid recipient',
-        'is not a known user',
-        'is not a valid mailbox',
-        'is not an active address at this host',
-        'mailbox does not exist',
-        'mailbox invalid',
-        'mailbox is inactive',
-        'mailbox is unavailable',
-        'mailbox not present',
-        'mailbox not found',
-        'mailbox unavaiable',
-        'nessun utente simile in questo indirizzo',
-        'no account by that name here',
-        'no existe dicha persona',
-        'no existe ese usuario ',
-        'no mail box available for this user',
-        'no mailbox by that name is currently available',
-        'no mailbox found',
-        'no such address here',
-        'no such mailbox',
-        'no such person at this address',
-        'no such recipient',
-        'no such user',
-        'no thank you rejected: account unavailable',
-        'no valid recipients, bye',
-        'not a valid recipient',
-        'not a valid user here',
-        'not a local address',
-        'not email addresses',
-        'recipient address rejected. (in reply to rcpt to command)',
-        'recipient address rejected: access denied',
-        'recipient address rejected: invalid user',
-        'recipient address rejected: invalid-recipient',
-        'recipient address rejected: unknown user',
-        'recipient address rejected: userunknown',
-        'recipient does not exist',
-        'recipient is not accepted',
-        'recipient is not local',
-        'recipient not exist',
-        'recipient not found',
-        'recipient not ok',
-        'recipient refuses to accept your mail',
-        'recipient unknown',
-        'requested action not taken: mailbox unavailable',
-        'resolver.adr.recipient notfound',
-        'sorry, user unknown',
-        'sorry, badrcptto',
-        'sorry, no mailbox here by that name',
-        'sorry, your envelope recipient has been denied',
-        "that domain or user isn't in my list of allowed rcpthosts",
-        'the email account that you tried to reach does not exist',
-        'the following recipients was undeliverable',
-        "the user's email name is not found",
-        'there is no one at this address',
-        'this address no longer accepts mail',
-        'this email address is wrong or no longer valid',
-        'this recipient is in my badrecipientto list',
-        'this recipient is not in my validrcptto list',
-        'this spectator does not exist',
-        'unknown mailbox',
-        'unknown recipient',
-        'unknown user',
-        'user does not exist',
-        'user missing home directory',
-        'user not active',
-        'user not exist',
-        'user not found',
-        'user not known',
-        'user unknown',
-        'utilisateur inconnu !',
-        'vdeliver: invalid or unknown virtual user',
-        'your envelope recipient is in my badrcptto list',
+        "destination addresses were unknown",
+        "destination server rejected recipients",
+        "domain or user isn't in my list of allowed rcpthosts",
+        "email account that you tried to reach does not exist",
+        "email address could not be found",
+        "invalid address",
+        "invalid mailbox",
+        "is not a known user",
+        "is not a valid mailbox",
+        "mailbox does not exist",
+        "mailbox invalid",
+        "mailbox not present",
+        "mailbox not found",
+        "nessun utente simile in questo indirizzo",
+        "no account by that name here",
+        "no existe dicha persona",
+        "no existe ese usuario ",
+        "no such recipient",
+        "no such user",
+        "no thank you rejected: account unavailable",
+        "no valid recipients, bye",
+        "not a valid recipient",
+        "not a valid user here",
+        "not a local address",
+        "not email addresses",
+        "recipient address rejected. (in reply to rcpt to command)",
+        "recipient address rejected: access denied",
+        "recipient address rejected: userunknown",
+        "recipient is in my badrecipientto list",
+        "recipient is not accepted",
+        "recipient is not in my validrcptto list",
+        "recipient is not local",
+        "recipient not ok",
+        "recipient refuses to accept your mail",
+        "recipient unknown",
+        "recipients was undeliverable",
+        "spectator does not exist",
+        "there is no one at this address",
+        "unknown mailbox",
+        "unknown recipient",
+        "unknown user",
+        "user missing home directory",
+        "user not known",
+        "user unknown",
+        "utilisateur inconnu !",
+        "weil die adresse nicht gefunden wurde oder keine e-mails empfangen kann",
+        "your envelope recipient has been denied",
     ];
     state $pairs = [
-        ['<', '> not found'],
-        ['<', '>... blocked by '],
-        ['account ', ' does not exist at the organization'],
-        ['adresse d au moins un destinataire invalide. invalid recipient.', '416'],
-        ['adresse d au moins un destinataire invalide. invalid recipient.', '418'],
-        ['bad', 'recipient'],
-        ['mailbox ', 'does not exist'],
-        ['mailbox ', 'unavailable or access denied'],
-        ['no ', ' in name directory'],
-        ['non', 'existent user'],
-        ['rcpt <', ' does not exist'],
-        ['rcpt (', 't exist '],
-        ['recipient ', ' was not found in'],
-        ['recipient address rejected: user ', '  does not exist'],
-        ['recipient address rejected: user unknown in ', '  table'],
-        ['said: 550-5.1.1 ', ' user unknown '],
-        ['said: 550 5.1.1 ', ' user unknown '],
+        ["<", "> not found"],
+        ["<", ">... blocked by "],
+        ["account ", " does not exist at the organization"],
+        ["address", " no longer"],
+        ["address", " not exist"],
+        ["bad", "recipient"],
+        ["invalid", "recipient"],
+        ["invalid", "user"],
+        ["mailbox ", "does not exist"],
+        ["mailbox ", "unavailable"],
+        ["no ", " in name directory"],
+        ["no ", "mail", "box "],
+        ["no ", "such", "address"],
+        ["non", "existent user"],
+        ["rcpt <", " does not exist"],
+        ["rcpt (", "t exist "],
+        ["recipient no", "found"],
+        ["recipient ", " not exist"],
+        ["recipient ", " was not found in"],
         ["this user doesn't have a ", " account"],
-        ['unknown e', 'mail address'],
-        ['unknown local', 'part'],
-        ['user ', ' was not found'],
-        ['user ', ' does not exist'],
-        ['user (', ') unknown'],
+        ["unknown e", "mail address"],
+        ["unknown local", "part"],
+        ["user ", " not exist"],
+        ["user ", "not found"],
+        ["user (", ") unknown"],
     ];
 
     return 1 if grep { rindex($argv1, $_) > -1 } @$index;
@@ -143,7 +112,11 @@ sub true {
     # @since v4.0.0
     # @see http://www.ietf.org/rfc/rfc2822.txt
     my $class = shift;
-    my $argvs = shift // return 0; return 1 if $argvs->{'reason'} eq 'userunknown';
+    my $argvs = shift // return 0;
+
+    require Sisimai::SMTP::Command;
+    return 1 if $argvs->{'reason'} eq 'userunknown';
+    return 0 if grep { $argvs->{'command'} eq $_ } Sisimai::SMTP::Command->BeforeRCPT->@*;
 
     my $tempreason = Sisimai::SMTP::Status->name($argvs->{'deliverystatus'}) || '';
     return 0 if $tempreason eq 'suspend';
@@ -238,7 +211,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2025 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2026 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
