@@ -15,8 +15,8 @@ sub find {
     return '' unless Sisimai::SMTP::Reply->test($argvs->{'replycode'});
 
     state $messagesof = {
-        # https://community.mimecast.com/s/article/Mimecast-SMTP-Error-Codes-842605754
-        # https://community.mimecast.com/s/article/email-security-cloud-gateway-mimecast-smtp-error-codes
+        # - https://community.mimecast.com/s/article/email-security-cloud-gateway-mimecast-smtp-error-codes
+        # - https://mimecastsupport.zendesk.com/hc/en-us/articles/34000709564691-Policies-Mimecast-SMTP-Error-Codes
         'authfailure' => [
             # - The inbound message has been rejected because the originated IP address isn't list-
             #   ed in the published SPF records for the sending domain.
@@ -55,6 +55,8 @@ sub find {
             [550, 'local ct ip reputation - (reject)'],
         ],
         'blocked' => [
+            # - Sender address blocked.
+            #   A Blocked Senders Policy has blocked the sender's IP address.
             # - The sender's IP address has been blocked by a Blocked Senders Policy.
             # - Remove the entry from the policy.
             [421, 'sender address blocked'],
@@ -76,6 +78,15 @@ sub find {
             #   the associated IP address from the RBL.
             #[550, '< details of RBL >'], NEED AN ACTUAL ERROR MESSAGE STRING
         ],
+        'emailtoolarge' => [
+            # - The email size either exceeds an Email Size Limit policy or is larger than the
+            #   Mimecast service limit. The default is 100 MB for the Legacy MTA, and 200 MB for
+            #   "the Latest MTA".
+            # - Resend the message ensuring it's smaller than the limitation set. The transmission
+            #   and content-encoding can add significantly to the total message size (e.g. a mes-
+            #   sage with a 70 MB attachment, can have an overall size larger than 100 MB).
+            [554, 'maximum email size exceeded'],
+        ],
         'expired' => [
             # - Journal messages past the expiration
             # - Attempts are being made to journal mail past the set expiry threshold.
@@ -83,9 +94,17 @@ sub find {
             #   if rejected, causing the journal queue to grow.
             # - Check to confirm there are no significant time discrepancies on the mail server.
             #   Discontinue journaling old messages past the expiry threshold.
-            [550, 'Journal messages past the expiration'],
+            [550, 'journal messages past the expiration'],
         ],
         'failedstarttls' => [
+            # - SMTP inbound TLS has been enabled but no SSL certificate (or no valid certificate)
+            #   has been selected to be used. 
+            # - Delete or change the Secure Receipt or Secure Delivery policy enforcing TLS.
+            #   Alternatively, ensure the certificates on the mail server haven't expired.
+            #   If using a proxy server, ensure it isn't intercepting the traffic and modifying
+            #   encryption parameters.
+            ["454", "tls not available due to temporary reason"],
+
             # - This email has been sent using SMTP, but TLS is required by policy.
             # - Delete or change the Secure Receipt or Secure Delivery policy enforcing TLS.
             #   Alternatively, ensure the certificates on the mail server haven't expired. If using
@@ -111,15 +130,6 @@ sub find {
             # - Check you DNS has the required umbrella accounts listed as comma-separated values.
             [554, 'configuration is invalid for this certificate'],
         ],
-        'mesgtoobig' => [
-            # - The email size either exceeds an Email Size Limit policy or is larger than the
-            #   Mimecast service limit. The default is 100 MB for the Legacy MTA, and 200 MB for
-            #   "the Latest MTA".
-            # - Resend the message ensuring it's smaller than the limitation set. The transmission
-            #   and content-encoding can add significantly to the total message size (e.g. a mes-
-            #   sage with a 70 MB attachment, can have an overall size larger than 100 MB).
-            [554, 'maximum email size exceeded'],
-        ],
         'networkerror' => [
             # - The recipients' domains have MX records configured incorrectly
             # - Check and remove any MX records that point to hostnames with outbound references.
@@ -180,6 +190,31 @@ sub find {
             [554, 'host network not allowed'],
             [554, 'host network, not allowed'],
         ],
+        'ratelimited' => [
+            # - There are too many concurrent inbound connections for the account. The default is 20.
+            # - The IP address is automatically removed from the block list after five minutes.
+            #   Continued invalid connections result in the IP being readded to the block list. En-
+            #   sure you don't route outbound or journal messages to Mimecast from an IP address
+            #   that hasn't been authorized to do so.
+            [451, 'account service is temporarily unavailable'],
+
+            # - The sending server issues more than 100 RCPT TO entries. By default, Mimecast only
+            #   accepts 100 RCPT TO entries per message body (DATA). The error triggers the sending
+            #   mail server to provide the DATA for the first 100 recipients before it provides the
+            #   next batch of RCPT TO entries.
+            # - Most mail servers respect the transient error and treat it as a "truncation request".
+            #   If your mail server, firewall, or on-site solution doesn't respect the error, you
+            #   must ensure that no more than 100 recipients are submitted.
+            #   Note:
+            #       Solutions like SMTP Fix-Up / MailGuard and ESMTP inspection on Cisco Pix and
+            #       ASA Firewalls are known not to respect the transient error. We advise you to
+            #       disable this functionality.
+            [452, 'too many recipients'],
+
+            # - There are too many concurrent outbound connections for the account.
+            # - Send the messages in smaller chunks to recipients.
+            [550, 'exceeding outbound thread limit'],
+        ],
         'rejected' => [
             # - The sender's email address or domain has triggered a Blocked Senders Policy or
             #   there's an SPF hard rejection.
@@ -208,6 +243,19 @@ sub find {
             [550, 'submitter failed to disabled'],
             [550, 'submitter failed to authenticate'],
         ],
+        'spamdetected' => [
+            # - A signature was detected that could either be a virus, or a spam score over the
+            #   maximum threshold. The spam score isn't available in the Administration Console. If
+            #   you aren't a Mimecast customer but have emails rejected with this error code, con-
+            #   tact the recipient to adjust their configuration and permit your address. If unsuc-
+            #   cessful, your IT department can submit a request to review these email rejections
+            #   via our Sender Feedback form.
+            # - Anti-virus checks cannot be bypassed. Contact the sender to see if they can stop
+            #   these messages from being blocked. Anti-spam checks can be bypassed using a Per-
+            #   mitted Senders or Auto Allow policy. Rejected emails can be viewed in your Outbound
+            #   Activity and searching for the required email address.
+            [554, 'email rejected due to security policies'],
+        ],
         'systemerror' => [
             # - The Mimecast server is under maximum load.
             # - No action is required from the end-user. The message will retry 30 times and when
@@ -231,31 +279,6 @@ sub find {
             # - Contact Mimecast Support.
             [451, 'unable to process an email at this time'],
         ],
-        'toomanyconn' => [
-            # - There are too many concurrent inbound connections for the account. The default is 20.
-            # - The IP address is automatically removed from the block list after five minutes.
-            #   Continued invalid connections result in the IP being readded to the block list. En-
-            #   sure you don't route outbound or journal messages to Mimecast from an IP address
-            #   that hasn't been authorized to do so.
-            [451, 'account service is temporarily unavailable'],
-
-            # - The sending server issues more than 100 RCPT TO entries. By default, Mimecast only
-            #   accepts 100 RCPT TO entries per message body (DATA). The error triggers the sending
-            #   mail server to provide the DATA for the first 100 recipients before it provides the
-            #   next batch of RCPT TO entries.
-            # - Most mail servers respect the transient error and treat it as a "truncation request".
-            #   If your mail server, firewall, or on-site solution doesn't respect the error, you
-            #   must ensure that no more than 100 recipients are submitted.
-            #   Note:
-            #       Solutions like SMTP Fix-Up / MailGuard and ESMTP inspection on Cisco Pix and
-            #       ASA Firewalls are known not to respect the transient error. We advise you to
-            #       disable this functionality.
-            [452, 'too many recipients'],
-
-            # - There are too many concurrent outbound connections for the account.
-            # - Send the messages in smaller chunks to recipients.
-            [550, 'exceeding outbound thread limit'],
-        ],
         'userunknown' => [
             # - The email address isn't a valid SMTP address.
             # - The sender must resend the message to a valid internal email address.
@@ -273,19 +296,6 @@ sub find {
             # - The sender must resend the message to a valid internal recipient address.
             [550, 'invalid recipient'],
         ],
-        'virusdetected' => [
-            # - A signature was detected that could either be a virus, or a spam score over the
-            #   maximum threshold. The spam score isn't available in the Administration Console. If
-            #   you aren't a Mimecast customer but have emails rejected with this error code, con-
-            #   tact the recipient to adjust their configuration and permit your address. If unsuc-
-            #   cessful, your IT department can submit a request to review these email rejections
-            #   via our Sender Feedback form.
-            # - Anti-virus checks cannot be bypassed. Contact the sender to see if they can stop
-            #   these messages from being blocked. Anti-spam checks can be bypassed using a Per-
-            #   mitted Senders or Auto Allow policy. Rejected emails can be viewed in your Outbound
-            #   Activity and searching for the required email address.
-            [554, 'email rejected due to security policies'],
-        ],
     };
 
     my $issuedcode = lc $argvs->{'diagnosticcode'} // 0;
