@@ -3,7 +3,6 @@ use v5.26;
 use strict;
 use warnings;
 use Encode;
-use Digest::SHA;
 
 my $EncodingsC = [qw/big5-eten gb2312/];
 my $EncodingsE = [qw/iso-8859-1/];
@@ -11,24 +10,6 @@ my $EncodingsJ = [qw/7bit-jis iso-2022-jp euc-jp shiftjis/];
 use Encode::Guess; Encode::Guess->add_suspects(@$EncodingsC, @$EncodingsE, @$EncodingsJ);
 sub encodenames { return [@$EncodingsC, @$EncodingsE, @$EncodingsJ] };
 
-sub token {
-    # Create the message token from an addresser and a recipient
-    # @param    [String] addr1  A sender's email address
-    # @param    [String] addr2  A recipient's email address
-    # @param    [Integer] epoch Machine time of the email bounce
-    # @return   [String]        Message token(MD5 hex digest) or empty string
-    #                           if the any argument is missing
-    # @see       http://en.wikipedia.org/wiki/ASCII
-    # @see       https://metacpan.org/pod/Digest::MD5
-    my $class = shift || return '';
-    my $addr1 = shift || return '';
-    my $addr2 = shift || return '';
-    my $epoch = shift // return '';
-
-    # Format: STX(0x02) Sender-Address RS(0x1e) Recipient-Address ETX(0x03)
-    return Digest::SHA::sha1_hex(sprintf("\x02%s\x1e%s\x1e%d\x03", lc $addr1, lc $addr2, $epoch));
-}
-
 sub is_8bit {
     # The argument is 8-bit text or not
     # @param    [String] argv1  Any string to be checked
@@ -177,7 +158,6 @@ Sisimai::String - String related class
     my $r = 'envelope-recipient@example.org';
     my $t = time();
 
-    print Sisimai::String->token($s, $r, $t);  # 2d635de42a44c54b291dda00a93ac27b
     print Sisimai::String->is_8bit(\'猫');     # 1
     print Sisimai::String->sweep(' neko cat ');# 'neko cat'
 
@@ -190,16 +170,6 @@ C<Sisimai::String> provide utilities for dealing various strings
 
 =head1 CLASS METHODS
 
-=head2 C<B<token(I<sender>, I<recipient>)>>
-
-C<token()> method generates a C<token>: an unique string generated by the envelope sender address
-and the envelope recipient address.
-
-    my $s = 'envelope-sender@example.jp';
-    my $r = 'envelope-recipient@example.org';
-
-    print Sisimai::String->token($s, $r);    # 2d635de42a44c54b291dda00a93ac27b
-
 =head2 C<B<is_8bit(I<Reference to String>)>>
 
 C<is_8bit()> method checks the argument include any 8bit character or not.
